# icdk (IC Deveplopment Toolkit)

## uvmgen

### 1. agent

- mon2cov_con_approach 
  Which approach would you like to use for monitor's connection with observers(scoreboard,coverage etc.)?
     1) Callbacks approach ;
     2) Analysis port usage in monitor
- drv_type
  pull driver or push driver?
